# Welcome to pydagroas
![alt text](images/pydagoras.png "pydagoras")

## Introduction
pydagoras is a Python package to create a Directed Acyclic Graph [DAG](https://en.wikipedia.org/wiki/Directed_acyclic_graph) </br>

<b>This site is currenlty under the later stages of construction. </br> 
Please be patient, or even better give some feedback, and come back later to see what has changed.
</b>
</br>
</br>
The aim of this site is to document;

* A [demo site](https://pydagoras.com)  where the example app can be seen and used.
* An example app that uses `pydagoras`.
* The pypi package [pydagoras](https://pypi.org/project/pydagoras) that underpins the demo site.

## [Demo](demo.md)
This section links to the demo site, it details how to use the demo site and to make and see changes to the DAGs.
It also shows shows screenshots of example DAGs, as well as a video site showing three example pydagoras DAGs being updated.

## [Example use](example_use.md)
This section details an example of a front end, that connects to a backend pydagoras DAG, and shows the DAG graphicaly as it updates.

## [Package](package.md)
pydagoras can be installed from PyPi, which can be reached using the Python link the bottom right corner of this page.</br>
The package section details;

* Other ways to get pydagoras
* What is included in the package
* How to constuct a DAG using pydagoras by creating and linking nodes
* Updating inputs
* Accessing the output

## [Code reference](reference.md)
This section allows you to look into the code behind the pydagoras package.
